@@ -8,7 +8,7 @@ from PIL import Image
 from ..resource_pack.item_models import handle_item		# Handle new items models (used for the manual and the heavy workbench)
 from ..utils.database_helper import add_item_name_and_lore_if_missing
 from ..utils.ingredients import ingr_repr, ingr_to_id
-from ..utils.io import super_copy, write_all_files, super_merge_dict, delete_file, write_to_load_file
+from ..utils.io import super_copy, write_all_files, super_merge_dict, delete_file, write_load_file
 from ..constants import CUSTOM_BLOCK_VANILLA, OVERRIDE_MODEL, RESULT_OF_CRAFTING, USED_FOR_CRAFTING, OFFICIAL_LIBS, CATEGORY, WIKI_COMPONENT
 from .shared_import import (
 	TEMPLATES_PATH, MANUAL_ASSETS_PATH, HEAVY_WORKBENCH_CATEGORY, FONT_FILE, SMALL_NONE_FONT,
@@ -632,7 +632,7 @@ def routine(config: dict):
 	first_page: str = json.dumps(book_content[0], ensure_ascii=False)
 	for r in [("\\n", "\\\\n"), (', "underlined": true','')]:
 		first_page = first_page.replace(*r)
-	write_to_load_file(config, f"""
+	write_load_file(config, f"""
 # Register the manual to the universal manual
 execute unless data storage python_datapack:main universal_manual run data modify storage python_datapack:main universal_manual set value []
 data remove storage python_datapack:main universal_manual[{{"name":"{project_name}"}}]
